.. currentmodule:: pyfits

*********
HDU Lists
*********

.. inheritance-diagram:: HDUList

`HDUList`
=========

.. autoclass:: HDUList
   :members: append, insert, close, flush, index_of, info, filename, readall, update_extend, verify, writeto, fileinfo
   :undoc-members:
   :show-inheritance:
